@@ -66,7 +66,7 @@ def build_model(model_name):
 
 	return model_obj[model_name]
 
-def verify(img1_path, img2_path = '', model_name = 'VGG-Face', distance_metric = 'cosine', model = None, enforce_detection = True, detector_backend = 'opencv', align = True, prog_bar = True, normalization = 'base', use_threshold = False):
+def verify(img1_path, img2_path = '', model_name = 'VGG-Face', distance_metric = 'cosine', model = None, enforce_detection = True, detector_backend = 'opencv', align = True, prog_bar = True, normalization = 'base'):
 
 	"""
 	This function verifies an image pair is same person or different persons.
@@ -194,14 +194,12 @@ def verify(img1_path, img2_path = '', model_name = 'VGG-Face', distance_metric =
 
 						threshold = dst.findThreshold(i, j)
 						
-						if use_threshold:
-							if distance <= threshold:
-								identified = True
-							else:
-								identified = False
-						else:
+						
+						if distance <= threshold:
 							identified = True
-
+						else:
+							identified = False
+						
 						resp_obj = {
 							"verified": identified
 							, "distance": distance
@@ -469,7 +467,7 @@ def analyze(img_path, actions = ('emotion', 'age', 'gender', 'race') , models =
 
 		return resp_obj
 
-def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine', model = None, enforce_detection = True, detector_backend = 'opencv', align = True, prog_bar = True, normalization = 'base'):
+def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine', model = None, enforce_detection = True, detector_backend = 'opencv', align = True, prog_bar = True, normalization = 'base', use_threshold = False):
 
 	"""
 	This function applies verification several times and find an identity in a database
@@ -654,7 +652,11 @@ def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine',
 						if model_name != 'Ensemble':
 							threshold = dst.findThreshold(j, k)
 							df = df.drop(columns = ["%s_representation" % (j)])
-							df = df[df["%s_%s" % (j, k)] <= threshold]
+							
+							if use_threshold:
+								df = df[df["%s_%s" % (j, k)] <= threshold]
+							else:
+								df = df[df["%s_%s" % (j, k)]]
 
 							df = df.sort_values(by = ["%s_%s" % (j, k)], ascending=True).reset_index(drop=True)
 
